@@ -148,9 +148,11 @@ namespace SIPWITCH_NAMESPACE {
 
         signals::start();
         events::start();
+        notify::start();
         server::run();
 
         events::terminate("server shutdown");
+        notify::stop();
         signals::stop();
         service::shutdown();
         control::release();
@@ -501,5 +503,5 @@ static SERVICE_MAIN(main, argc, argv)
 PROGRAM_MAIN(argc, argv)
 {
     init(argc, argv, false, &service_main);
-    PROGRAM_EXIT(0);
+    PROGRAM_EXIT(server::exit_code);
 }
